@@ -120,13 +120,14 @@ impl<'de> Deserialize<'de> for CDuration {
 #[derive(Clone, Debug, Deserialize)]
 pub struct ConcurrencyProfile {
 	pub parser_concurrency: usize,
+	pub parser_pin:         usize,
 	pub domain_concurrency: usize,
 }
 
 impl Default for ConcurrencyProfile {
 	fn default() -> Self {
 		let physical_cores = num_cpus::get_physical();
-		Self { parser_concurrency: physical_cores, domain_concurrency: physical_cores * 40 }
+		Self { parser_concurrency: physical_cores, parser_pin: 0, domain_concurrency: physical_cores * 40 }
 	}
 }
 
@@ -244,7 +245,7 @@ impl Default for CrawlingSettings {
 			job_hard_timeout:          CDuration::from_secs(60),
 			job_soft_timeout:          CDuration::from_secs(30),
 			load_timeout:              CDuration::from_secs(10),
-			user_agent:                Some(String::from("crusty-core/0.46.0")),
+			user_agent:                Some(String::from("crusty-core/0.47.0")),
 			compression:               true,
 			custom_headers:            HashMap::new(),
 			max_response_size:         CBytes(1024 * 1024 * 2),
